@@ -1,13 +1,8 @@
 import os
 
-from .main import (
-    PathFactory,
-    PurePathFactory,
-    load_pathlib_monkey_patch,
-    load_uri_backends_from_plugins,
-)
+from .main import PathFactory, PurePathFactory, load_pathlib_monkey_patch
 
-__version__ = "0.1.0"
+__version__ = "0.1.2"
 
 __all__ = [
     "load_pathlib_monkey_patch",
@@ -16,8 +11,6 @@ __all__ = [
 ]
 
 
-load_uri_backends_from_plugins()
-
 if os.environ.get("URI_PATHLIB_FACTORY_LOAD_PATHLIB_PATCH", "").lower() in [
     "1",
     "true",
